/*
 *  flower.cpp
 *  emptyExample
 *
 *  Created by Andrew Wallace on 9/15/11.
 *  Copyright 2011 Cool Town Inc. All rights reserved.
 *
 */

#include "Flower.h"

/*
 *  circleTug.cpp
 *  emptyExample
 *
 *  Created by Andrew Wallace on 9/15/11.
 *  Copyright 2011 Cool Town Inc. All rights reserved.
 *
 */

#include "circleTug.h"

//--------------------------------------------------------------
void Flower::setup(){
	
	startDraw=true;
	
	done=false;
	
	//clear the points if there are any there
	pnts.clear();
	
	//set up the current pos
	curPos.setup(0,200,false);
	insideDist=170;
	
	//and the orbit
	orbitAngle=0;
	orbitDist=50;
	
	animationStartTime=ofGetElapsedTimeMillis();
}

//--------------------------------------------------------------
void Flower::update(){
	float growTime=5000;
	float shrinkTime=growTime+5000;
	
	//get the current animation time
	int curTime=ofGetElapsedTimeMillis()-animationStartTime;
	
	if (startDraw){
		curPos.a+=0.01;
		
		//set the orbit
		orbitAngle+=0.1;
		orbitX=curPos.getX()+cos(orbitAngle)*orbitDist;
		orbitY=curPos.getY()+sin(orbitAngle)*orbitDist;
		
		//add this point the the vector
		rPoint newPoint;
		newPoint.setupXY(orbitX, orbitY, false);
		//is it inside?
		if (newPoint.d<insideDist)	newPoint.inside=true;
		pnts.push_back(newPoint);
		
		//have we made a full rotation? If so, stop drawing
		if (curPos.a>TWO_PI+0.02){
			startDraw=false;
			animationStartTime=ofGetElapsedTimeMillis();
		}
	}
	
	//if we're done drawing, start manipulating the points
	else if (curTime<growTime){
		for (int i=0; i<pnts.size(); i++){
			//push all of the inside points out
			if (pnts[i].inside)	
				pnts[i].xenoToDist(100,0.005);
			else	//and vice vera
				pnts[i].xenoToDist(300,0.005);
			//and spin them all
			pnts[i].a+=ofMap(sin((float)curTime/1000), -1, 1, 0.001, 0.03);
		}
	}
	else if (curTime<shrinkTime){
		for (int i=0; i<pnts.size(); i++){
			//push all of points to a circle
			pnts[i].xenoToDist(200,0.05);
		
			//and spin the other way
			pnts[i].a+=-ofMap(sin((float)curTime/1000), -1, 1, 0.003, 0.06);
		}
	}
	else{
		done=true;
	}

			
	
}

//--------------------------------------------------------------
void Flower::draw(){
	cout<<startDraw<<endl;
	
	ofPushMatrix();
	ofTranslate(ofGetWidth()/2, ofGetHeight()/2);
	
	//Shows the locaiton of the curPos and orbit
	/*
	ofSetColor(244, 0, 0);
	ofCircle(curPos.getX(), curPos.getY(), 10);
	float x=curPos.getX()+cos(orbitAngle)*orbitDist;
	float y=curPos.getY()+sin(orbitAngle)*orbitDist;
	ofSetColor(0, 255, 0);
	ofCircle(x, y, 5);
	 */
	
	ofSetColor(255, 255, 255);
	ofNoFill();
	ofBeginShape();
	for (int i=0; i<pnts.size(); i++)
		ofVertex(pnts[i].getX(), pnts[i].getY());
	ofEndShape(false);
	
	ofPopMatrix();
	
	
}