#include "testApp.h"

//--------------------------------------------------------------
void testApp::setup(){
	
	ofSetVerticalSync(true);
	ofEnableAlphaBlending();
	ofBackground(0, 0, 0);
	
	ofSetFrameRate(60);
	
	cycle=0;
	timer=0;
	
	//start with flower
	flower.setup();	
	circleTug.setup();	//circle tug can be set up, though
	phase.setup();

}

//--------------------------------------------------------------
void testApp::update(){
	timer++;
	
	if (cycle==0){
		flower.update();
		if (flower.done){
			cycle++;
			circleTug.setup();
			timer=0;
		}
	}
	//after flower, there is a single circle of radius 200 in the center of the screen
	//circle tug requires 36 circles of radius 100, spaced across the screen
	
	if (cycle==2){
		circleTug.update();
		if (circleTug.done){
			cycle++;
			timer=0;
		}
	}
	
	//still need to update circleTug durign transition
	if (cycle==3)
		circleTug.update();
	
	if (cycle==4){
		phase.update();
		if (phase.done){
			cycle=0;	//start it over
			flower.setup();	//reset the flower
		}
	}
	

}

//--------------------------------------------------------------
void testApp::draw(){
	
	//flower
	if (cycle==0)
		flower.draw();
	
	//transition between flower and circle tug
	if (cycle==1){
		int timerEnd=200;
		float prc=ofMap(timer, 0, timerEnd, 0, 1, true);
		prc=powf(prc, 3);
		for (int x=0; x<6; x++){
			for (int y=0; y<6; y++){
				float xPos=ofMap(prc, 0, 1, ofGetWidth()/2, (circleTug.expandDist*x)*1.8);
				float yPos=ofMap(prc, 0, 1, ofGetHeight()/2, (circleTug.expandDist*y)*1.8);
				float rad=ofMap(prc, 0, 1, 200, 100);
				ofCircle(xPos,yPos,rad);
			}
		}
		if (timer==timerEnd){
			cycle++;
		}
		
	}

	//circle tug
	if (cycle==2){
		for (int x=0; x<6; x++){
			for (int y=0; y<6; y++){
				ofPushMatrix();
				ofTranslate((circleTug.expandDist*x)*1.8, (circleTug.expandDist*y)*1.8);
				if (y%2==0)	ofScale(1, -1);
				circleTug.draw();
				
				ofPopMatrix();
			}
		}
	}
	
	//condesnse the circle tug shapes into one line
	if (cycle==3){
		int timerEnd=200;
		float prc=ofMap(timer, 0, timerEnd, 0, 1, true);
		for (int x=0; x<6; x++){
			for (int y=0; y<6; y++){
				float yPos=ofMap(prc, 0, 1, (circleTug.expandDist*y)*1.8, 700);
				ofPushMatrix();
				ofTranslate((circleTug.expandDist*x)*1.8, yPos);
				if (y%2==0)	ofScale(1, -1);
				circleTug.draw();
				
				ofPopMatrix();
			}
		}
		
		if (timer==timerEnd){
			cycle++;
			phase.setup();		//reset the timer for phase
		}
		
	}
	
	
	if(cycle==4)
		phase.draw();
	
}

//--------------------------------------------------------------
void testApp::keyPressed(int key){

}

//--------------------------------------------------------------
void testApp::keyReleased(int key){

}

//--------------------------------------------------------------
void testApp::mouseMoved(int x, int y ){

}

//--------------------------------------------------------------
void testApp::mouseDragged(int x, int y, int button){

}

//--------------------------------------------------------------
void testApp::mousePressed(int x, int y, int button){
}

//--------------------------------------------------------------
void testApp::mouseReleased(int x, int y, int button){

}

//--------------------------------------------------------------
void testApp::windowResized(int w, int h){

}

//--------------------------------------------------------------
void testApp::gotMessage(ofMessage msg){

}

//--------------------------------------------------------------
void testApp::dragEvent(ofDragInfo dragInfo){ 

}